@@ -154,11 +154,9 @@ class EmulationEnvController:
 
         current_step += 1
         Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Start SDN controller --")
-        SDNControllerManager.start_ryu(emulation_env_config=emulation_env_config)
-
-        current_step += 1
-        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Start SDN controller monitor --")
-        SDNControllerManager.start_ryu_monitor(emulation_env_config=emulation_env_config)
+        if emulation_env_config.sdn_controller_config is not None:
+            SDNControllerManager.start_ryu(emulation_env_config=emulation_env_config)
+            time.sleep(10)
 
         current_step += 1
         Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Creating resource constraints --")
@@ -181,9 +179,9 @@ class EmulationEnvController:
         EmulationEnvController.ping_all(emulation_env_config=emulation_env_config)
 
         current_step += 1
-        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Start Kafka producer at "
-                                            f"SDN controller --")
-        SDNControllerManager.start_controller_producer(emulation_env_config=emulation_env_config)
+        Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Start SDN controller monitor --")
+        if emulation_env_config.sdn_controller_config is not None:
+            SDNControllerManager.start_ryu_monitor(emulation_env_config=emulation_env_config)
 
         current_step += 1
         Logger.__call__().get_logger().info(f"-- Step {current_step}/{steps}: Creating users --")
