@@ -39,7 +39,6 @@ class SDNControllerManager:
                 ip=emulation_env_config.sdn_controller_config.container.get_ips()[0]))
 
         if constants.COMMANDS.SEARCH_RYU_MANAGER not in str(o):
-
             Logger.__call__().get_logger().info(
                 f"Starting ryu manager on node: "
                 f"{emulation_env_config.sdn_controller_config.container.get_ips()[0]}")
@@ -164,8 +163,8 @@ class SDNControllerManager:
             stub = csle_collector.ryu_manager.ryu_manager_pb2_grpc.RyuManagerStub(channel)
             Logger.__call__().get_logger().info(
                 f"Starting RYU, port: {emulation_env_config.sdn_controller_config.controller_port}, "
-                  f"web_port: {emulation_env_config.sdn_controller_config.controller_web_api_port}, "
-                  f"controller: {emulation_env_config.sdn_controller_config.controller_module_name}")
+                f"web_port: {emulation_env_config.sdn_controller_config.controller_web_api_port}, "
+                f"controller: {emulation_env_config.sdn_controller_config.controller_module_name}")
             ryu_dto = csle_collector.ryu_manager.query_ryu_server.start_ryu(
                 stub, port=emulation_env_config.sdn_controller_config.controller_port,
                 web_port=emulation_env_config.sdn_controller_config.controller_web_api_port,
@@ -262,7 +261,7 @@ class SDNControllerManager:
                 running = True
             except Exception as e:
                 running = False
-                Logger.__call__().get_logger().debug(
+                Logger.__call__().get_logger().warn(
                     f"Could not fetch Ryu manager status on IP:{ip}, error: {str(e)}, {repr(e)}")
             if status is not None:
                 ryu_managers_statuses.append(status)
